==> fujion-core-1.0.1-sources.jar: org/fujion/component/Listitem.java <==
/*
 * #%L
 * fujion
 * %%
 * Copyright (C) 2008 - 2016 Regenstrief Institute, Inc.
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * #L%
 */
package org.fujion.component;

import org.fujion.annotation.Component;
import org.fujion.annotation.Component.PropertyGetter;
import org.fujion.annotation.Component.PropertySetter;
import org.fujion.annotation.EventHandler;
import org.fujion.event.ChangeEvent;
import org.fujion.event.EventUtil;

/**
 * A single item within a list box.
 */
@Component(tag = "listitem", widgetClass = "Listitem", parentTag = "listbox")
public class Listitem extends BaseLabeledComponent<BaseLabeledComponent.LabelPositionNone> {
    
    private boolean selected;
    
    private String value;
    
    public Listitem() {
        super();
    }
    
    public Listitem(String label) {
        super(label);
    }
    
    protected void _setSelected(boolean selected, boolean notifyClient, boolean notifyParent) {
        if (selected != this.selected) {
            this.selected = selected;
            
            if (notifyClient) {
                sync("selected", selected);
            }
            
            if (notifyParent && getParent() != null) {
                getListbox()._updateSelected(this);
            }
        }
    }
    
    public Listbox getListbox() {
        return (Listbox) getParent();
    }
    
    @PropertyGetter("selected")
    public boolean isSelected() {
        return selected;
    }
    
    @PropertySetter("selected")
    public void setSelected(boolean selected) {
        _setSelected(selected, true, true);
    }
    
    @PropertyGetter("value")
    public String getValue() {
        return value;
    }
    
    @PropertySetter("value")
    public void setValue(String value) {
        if (!areEqual(value, this.value)) {
            sync("value", this.value = value);
        }
    }
    
    @EventHandler(value = "change", syncToClient = false)
    private void _onChange(ChangeEvent event) {
        _setSelected(defaultify(event.getValue(Boolean.class), true), false, true);
        event = new ChangeEvent(this.getParent(), event.getData(), this);
        EventUtil.send(event);
    }
    
}

==> fujion-core-1.0.9-sources.jar: org/fujion/component/Listitem.java <==
/*
 * #%L
 * fujion
 * %%
 * Copyright (C) 2008 - 2017 Regenstrief Institute, Inc.
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * #L%
 */
package org.fujion.component;

import org.fujion.annotation.Component;
import org.fujion.annotation.Component.PropertyGetter;
import org.fujion.annotation.Component.PropertySetter;
import org.fujion.annotation.EventHandler;
import org.fujion.event.ChangeEvent;
import org.fujion.event.EventUtil;

/**
 * A single item within a list box.
 */
@Component(tag = "listitem", widgetClass = "Listitem", parentTag = "listbox")
public class Listitem extends BaseLabeledComponent<BaseLabeledComponent.LabelPositionNone> {

    private boolean selected;

    private String value;

    public Listitem() {
        super();
    }

    public Listitem(String label) {
        super(label);
    }

    /**
     * Sets the selection state.
     *
     * @param selected The selection state.
     * @param notifyClient If true, notify the client of the state change.
     * @param notifyParent If true, notify the parent of the state change.
     */
    protected void _setSelected(boolean selected, boolean notifyClient, boolean notifyParent) {
        if (selected != this.selected) {
            this.selected = selected;

            if (notifyClient) {
                sync("selected", selected);
            }

            if (notifyParent && getParent() != null) {
                getListbox()._updateSelected(this);
            }
        }
    }

    /**
     * Returns the list box that is the parent of this list item.
     *
     * @return The parent list box (may be null).
     */
    public Listbox getListbox() {
        return (Listbox) getParent();
    }

    /**
     * Returns the selection state.
     *
     * @return The selection state.
     */
    @PropertyGetter("selected")
    public boolean isSelected() {
        return selected;
    }

    /**
     * Sets the selection state.
     *
     * @param selected The selection state.
     */
    @PropertySetter("selected")
    public void setSelected(boolean selected) {
        _setSelected(selected, true, true);
    }

    /**
     * Returns the value associated with the list item.
     *
     * @return The value associated with the list item.
     */
    @PropertyGetter("value")
    public String getValue() {
        return value;
    }

    /**
     * Sets the value associated with the list item.
     *
     * @param value The value associated with the list item.
     */
    @PropertySetter("value")
    public void setValue(String value) {
        if (!areEqual(value, this.value)) {
            sync("value", this.value = value);
        }
    }

    /**
     * Handles change events from the client.
     *
     * @param event A change event.
     */
    @EventHandler(value = "change", syncToClient = false)
    private void _onChange(ChangeEvent event) {
        _setSelected(defaultify(event.getValue(Boolean.class), true), false, true);
        event = new ChangeEvent(this.getParent(), event.getData(), this);
        EventUtil.send(event);
    }

}
